@@ -9,6 +9,10 @@ import os
 sys.path.append(os.path.join(os.pardir, "tests"))
 import kombu
 
+from django.conf import settings
+if not settings.configured:
+    settings.configure()
+
 # General configuration
 # ---------------------
 
@@ -25,7 +29,7 @@ master_doc = 'index'
 
 # General information about the project.
 project = u'Kombu'
-copyright = u'2009-2011, Ask Solem'
+copyright = u'2009-2012, Ask Solem'
 
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
