@@ -22,10 +22,7 @@ def wait_many(timeout=1):
     #: If hostname, userid, password and virtual_host is not specified
     #: the values below are the default, but listed here so it can
     #: be easily changed.
-    connection = BrokerConnection(hostname="localhost",
-                                  userid="guest",
-                                  password="guest",
-                                  virtual_host="/")
+    connection = BrokerConnection("amqp://guest:guest@localhost:5672//")
 
     #: SimpleQueue mimics the interface of the Python Queue module.
     #: First argument can either be a queue name or a kombu.Queue object.
@@ -42,5 +39,8 @@ def wait_many(timeout=1):
             spawn(message.ack)
             print(message.payload)
 
+    queue.close()
+    connection.close()
+
 
 spawn(wait_many).wait()
