@@ -10,14 +10,14 @@ priority_to_routing_key = {"high": "hipri",
                            "low": "lopri"}
 
 
-def send_as_task(connection, fun, args, kwargs, priority="mid"):
+def send_as_task(connection, fun, args=(), kwargs={}, priority="mid"):
     payload = {"fun": fun, "args": args, "kwargs": kwargs}
     routing_key = priority_to_routing_key[priority]
 
     with producers[connection].acquire(block=True) as producer:
         maybe_declare(task_exchange, producer.channel)
         producer.publish(payload, serializer="pickle",
-                                  compression="zlib",
+                                  compression="bzip2",
                                   routing_key=routing_key)
 
 if __name__ == "__main__":
