@@ -1,7 +1,7 @@
 from __future__ import with_statement
 
 from kombu.mixins import ConsumerMixin
-from kombu.utils import kwdict
+from kombu.utils import kwdict, reprcall
 
 from queues import task_queues
 
@@ -13,13 +13,17 @@ class Worker(ConsumerMixin):
 
     def get_consumers(self, Consumer, channel):
         return [Consumer(queues=task_queues,
-                        callbacks=[self.process_task])]
+                         callbacks=[self.process_task])]
 
     def process_task(self, body, message):
         fun = body["fun"]
         args = body["args"]
         kwargs = body["kwargs"]
-        fun(*args, **kwdict(kwargs))
+        self.info("Got task: %s", reprcall(fun.__name__, args, kwargs))
+        try:
+            fun(*args, **kwdict(kwargs))
+        except Exception, exc:
+            self.error("task raised exception: %r", exc)
         message.ack()
 
 if __name__ == "__main__":
@@ -28,4 +32,7 @@ if __name__ == "__main__":
     setup_logging(loglevel="INFO")
 
     with BrokerConnection("amqp://guest:guest@localhost:5672//") as conn:
-        Worker(conn).run()
+        try:
+            Worker(conn).run()
+        except KeyboardInterrupt:
+            print("bye bye")
