@@ -4,12 +4,17 @@ kombu.clocks
 
 Logical Clocks and Synchronization.
 
-:copyright: (c) 2009 - 2011 by Ask Solem.
+:copyright: (c) 2009 - 2012 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
+from __future__ import absolute_import
+from __future__ import with_statement
+
 from threading import Lock
 
+__all__ = ["LamportClock"]
+
 
 class LamportClock(object):
     """Lamport's logical clock.
@@ -55,16 +60,10 @@ class LamportClock(object):
         self.mutex = Lock()
 
     def adjust(self, other):
-        self.mutex.acquire()
-        try:
+        with self.mutex:
             self.value = max(self.value, other) + 1
-        finally:
-            self.mutex.release()
 
     def forward(self):
-        self.mutex.acquire()
-        try:
+        with self.mutex:
             self.value += 1
             return self.value
-        finally:
-            self.mutex.release()
