@@ -25,7 +25,7 @@ from Queue import Empty
 # (Issue #112)
 from kombu import exceptions
 from .transport import get_transport_cls
-from .utils import retry_over_time
+from .utils import cached_property, retry_over_time
 from .utils.compat import OrderedDict, LifoQueue as _LifoQueue
 from .utils.url import parse_url
 
@@ -79,21 +79,29 @@ class BrokerConnection(object):
     _transport = None
     _logger = None
     uri_passthrough = set(["sqla", "sqlalchemy"])
+    uri_prefix = None
+
+    #: The cache of declared entities is per connection,
+    #: in case the server loses data.
+    declared_entities = None
 
     def __init__(self, hostname="localhost", userid=None,
             password=None, virtual_host=None, port=None, insist=False,
             ssl=False, transport=None, connect_timeout=5,
-            transport_options=None, login_method=None, **kwargs):
+            transport_options=None, login_method=None, uri_prefix=None,
+            **kwargs):
         # have to spell the args out, just to get nice docstrings :(
         params = {"hostname": hostname, "userid": userid,
                   "password": password, "virtual_host": virtual_host,
                   "port": port, "insist": insist, "ssl": ssl,
                   "transport": transport, "connect_timeout": connect_timeout,
                   "login_method": login_method}
-        if hostname and "://" in hostname:
+        if hostname and "://" in hostname \
+                and transport not in self.uri_passthrough:
             if '+' in hostname[:hostname.index("://")]:
                 # e.g. sqla+mysql://root:masterkey@localhost/
                 params["transport"], params["hostname"] = hostname.split('+')
+                self.uri_prefix = params["transport"]
             else:
                 params.update(parse_url(hostname))
         self._init_params(**params)
@@ -109,6 +117,11 @@ class BrokerConnection(object):
             from .log import get_logger
             self._logger = get_logger("kombu.connection")
 
+        if uri_prefix:
+            self.uri_prefix = uri_prefix
+
+        self.declared_entities = set()
+
     def _init_params(self, hostname, userid, password, virtual_host, port,
             insist, ssl, transport, connect_timeout, login_method):
         self.hostname = hostname
@@ -159,7 +172,9 @@ class BrokerConnection(object):
         except (self.connection_errors + self.channel_errors):
             pass
 
-    def _close(self):
+    def _do_close_self(self):
+        # Closes only the connection and channel(s) not transport.
+        self.declared_entities.clear()
         if self._default_channel:
             self.maybe_close_channel(self._default_channel)
         if self._connection:
@@ -168,10 +183,13 @@ class BrokerConnection(object):
             except self.connection_errors + (AttributeError, socket.error):
                 pass
             self._connection = None
-            self._debug("closed")
+
+    def _close(self):
+        self._do_close_self()
         if self._transport:
             self._transport.client = None
             self._transport = None
+        self._debug("closed")
         self._closed = True
 
     def release(self):
@@ -261,7 +279,7 @@ class BrokerConnection(object):
                         raise
                     errback and errback(exc, 0)
                     self._connection = None
-                    self.close()
+                    self._do_close_self()
                     remaining_retries = None
                     if max_retries is not None:
                         remaining_retries = max(max_retries - retries, 1)
@@ -341,7 +359,10 @@ class BrokerConnection(object):
         transport_cls = self.transport_cls or "amqp"
         transport_cls = {"amqplib": "amqp"}.get(transport_cls, transport_cls)
         defaults = self.transport.default_connection_params
-        info = OrderedDict((("hostname", self.hostname),
+        hostname = self.hostname
+        if self.uri_prefix:
+            hostname = "%s+%s" % (self.uri_prefix, hostname)
+        info = OrderedDict((("hostname", hostname),
                             ("userid", self.userid),
                             ("password", self.password),
                             ("virtual_host", self.virtual_host),
@@ -351,7 +372,8 @@ class BrokerConnection(object):
                             ("transport", transport_cls),
                             ("connect_timeout", self.connect_timeout),
                             ("transport_options", self.transport_options),
-                            ("login_method", self.login_method)))
+                            ("login_method", self.login_method),
+                            ("uri_prefix", self.uri_prefix)))
         for key, value in defaults.iteritems():
             if info[key] is None:
                 info[key] = value
@@ -384,6 +406,8 @@ class BrokerConnection(object):
             url += ':' + str(port)
 
         url += '/' + quote(fields["virtual_host"])
+        if self.uri_prefix:
+            return "%s+%s" % (self.uri_prefix, url)
         return url
 
     def Pool(self, limit=None, preload=None):
@@ -545,6 +569,7 @@ class BrokerConnection(object):
         """
         if not self._closed:
             if not self.connected:
+                self.declared_entities.clear()
                 self._default_channel = None
                 self._connection = self._establish_connection()
                 self._closed = False
@@ -569,6 +594,13 @@ class BrokerConnection(object):
             self._transport = self.create_transport()
         return self._transport
 
+    @cached_property
+    def manager(self):
+        return self.transport.manager
+
+    def get_manager(self, *args, **kwargs):
+        return self.transport.get_manager(*args, **kwargs)
+
     @property
     def connection_errors(self):
         """List of exceptions that may be raised by the connection."""
