@@ -64,11 +64,7 @@ class Producer(object):
     def __init__(self, channel, exchange=None, routing_key=None,
             serializer=None, auto_declare=None, compression=None,
             on_return=None):
-        from .connection import BrokerConnection
-        if isinstance(channel, BrokerConnection):
-            channel = channel.default_channel
         self.channel = channel
-
         self.exchange = exchange or self.exchange
         if self.exchange is None:
             self.exchange = Exchange("")
@@ -79,11 +75,15 @@ class Producer(object):
         if auto_declare is not None:
             self.auto_declare = auto_declare
 
-        self.exchange = self.exchange(self.channel)
-        if self.auto_declare:
-            self.declare()
-        if self.on_return:
-            self.channel.events["basic_return"].append(self.on_return)
+        if self.channel:
+            self.revive(self.channel)
+
+    def __reduce__(self):
+        return self.__class__, self.__reduce_args__()
+
+    def __reduce_args__(self):
+        return (None, self.exchange, self.routing_key, self.serializer,
+                self.auto_declare, self.compression)
 
     def declare(self):
         """Declare the exchange.
@@ -167,8 +167,14 @@ class Producer(object):
         if isinstance(channel, BrokerConnection):
             channel = channel.default_channel
         self.channel = channel
+        self.exchange = self.exchange(channel)
         self.exchange.revive(channel)
 
+        if self.auto_declare:
+            self.declare()
+        if self.on_return:
+            self.channel.events["basic_return"].append(self.on_return)
+
     def __enter__(self):
         return self
 
@@ -259,27 +265,30 @@ class Consumer(object):
 
     def __init__(self, channel, queues=None, no_ack=None, auto_declare=None,
             callbacks=None, on_decode_error=None):
-        from .connection import BrokerConnection
-        if isinstance(channel, BrokerConnection):
-            channel = channel.default_channel
         self.channel = channel
-
-        self.queues = [] if queues is None else queues
-        if no_ack is not None:
-            self.no_ack = no_ack
+        self.queues = self.queues or [] if queues is None else queues
+        self.no_ack = self.no_ack if no_ack is None else no_ack
+        self.callbacks = (self.callbacks or [] if callbacks is None
+                                               else callbacks)
         if auto_declare is not None:
             self.auto_declare = auto_declare
         if on_decode_error is not None:
             self.on_decode_error = on_decode_error
 
-        if callbacks is not None:
-            self.callbacks = callbacks
-        if self.callbacks is None:
-            self.callbacks = []
-        self._active_tags = {}
+        if self.channel:
+            self.revive(self.channel)
 
+    def revive(self, channel):
+        """Revive consumer after connection loss."""
+        self._active_tags = {}
+        from .connection import BrokerConnection
+        if isinstance(channel, BrokerConnection):
+            channel = channel.default_channel
+        self.channel = channel
         self.queues = [queue(self.channel)
                             for queue in maybe_list(self.queues)]
+        for queue in self.queues:
+            queue.revive(channel)
 
         if self.auto_declare:
             self.declare()
@@ -442,12 +451,6 @@ class Consumer(object):
             raise NotImplementedError("Consumer does not have any callback")
         [callback(body, message) for callback in callbacks]
 
-    def revive(self, channel):
-        """Revive consumer after connection loss."""
-        for queue in self.queues:
-            queue.revive(channel)
-        self.channel = channel
-
     def _basic_consume(self, queue, consumer_tag=None,
             no_ack=no_ack, nowait=True):
         tag = self._active_tags.get(queue.name)
