@@ -1,5 +1,17 @@
+"""
+kombu.syn
+=========
+
+:copyright: (c) 2009 - 2012 by Ask Solem.
+:license: BSD, see LICENSE for more details.
+
+"""
+from __future__ import absolute_import
+
 import sys
 
+__all__ = ["detect_environment"]
+
 
 def blocking(fun, *args, **kwargs):
     return fun(*args, **kwargs)
