@@ -13,7 +13,7 @@ class Command(BaseCommand):
     requires_model_validation = True
 
     def handle(self, *args, **options):
-        from ...models import Message
+        from kombu.transport.django.models import Message
 
         count = Message.objects.filter(visible=False).count()
 
