@@ -4,13 +4,15 @@ kombu.transport.memory
 
 In-memory transport.
 
-:copyright: (c) 2009 - 2011 by Ask Solem.
+:copyright: (c) 2009 - 2012 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
+from __future__ import absolute_import
+
 from Queue import Queue
 
-from kombu.transport import virtual
+from . import virtual
 
 
 class Channel(virtual.Channel):
