@@ -20,13 +20,13 @@ from itertools import count
 from time import sleep, time
 from Queue import Empty
 
-from ...exceptions import StdChannelError
-from ...utils import emergency_dump_state, say
-from ...utils.compat import OrderedDict
-from ...utils.encoding import str_to_bytes, bytes_to_str
-from ...utils.finalize import Finalize
+from kombu.exceptions import StdChannelError
+from kombu.utils import emergency_dump_state, say
+from kombu.utils.compat import OrderedDict
+from kombu.utils.encoding import str_to_bytes, bytes_to_str
+from kombu.utils.finalize import Finalize
 
-from .. import base
+from kombu.transport import base
 
 from .scheduling import FairCycle
 from .exchange import STANDARD_EXCHANGE_TYPES
@@ -327,7 +327,6 @@ class Channel(AbstractChannel, base.StdChannel):
         # instantiate exchange types
         self.exchange_types = dict((typ, cls(self))
                     for typ, cls in self.exchange_types.items())
-        self.auto_delete_queues = {}
 
         self.channel_id = self.connection._next_channel_id()
 
@@ -368,8 +367,6 @@ class Channel(AbstractChannel, base.StdChannel):
 
     def queue_declare(self, queue, passive=False, auto_delete=False, **kwargs):
         """Declare queue."""
-        if auto_delete:
-            self.auto_delete_queues.setdefault(queue, 0)
         if passive and not self._has_queue(queue, **kwargs):
             raise StdChannelError("404",
                     u"NOT_FOUND - no queue %r in vhost %r" % (
@@ -435,8 +432,6 @@ class Channel(AbstractChannel, base.StdChannel):
         """Consume from `queue`"""
         self._tag_to_queue[consumer_tag] = queue
         self._active_queues.append(queue)
-        if queue in self.auto_delete_queues:
-            self.auto_delete_queues[queue] += 1
 
         def _callback(raw_message):
             message = self.Message(self, raw_message)
@@ -455,12 +450,6 @@ class Channel(AbstractChannel, base.StdChannel):
             self._consumers.remove(consumer_tag)
             self._reset_cycle()
             queue = self._tag_to_queue.pop(consumer_tag, None)
-            if queue in self.auto_delete_queues:
-                used = self.auto_delete_queues[queue]
-                if not used - 1:
-                    self.queue_delete(queue)
-                self.auto_delete_queues[queue] -= 1
-
             try:
                 self._active_queues.remove(queue)
             except ValueError:
@@ -590,7 +579,6 @@ class Channel(AbstractChannel, base.StdChannel):
             if self.connection is not None:
                 self.connection.close_channel(self)
         self.exchange_types = None
-        self.auto_delete_queues = None
 
     def encode_body(self, body, encoding=None):
         if encoding:
