@@ -101,7 +101,7 @@ def maybe_list(v):
 def fxrange(start=1.0, stop=None, step=1.0, repeatlast=False):
     cur = start * 1.0
     while 1:
-        if cur <= stop:
+        if not stop or cur <= stop:
             yield cur
             cur += step
         else:
