@@ -6,14 +6,18 @@ Execute cleanup handlers when objects go out of scope.
 
 Taken from :class:`multiprocessing.util.Finalize`.
 
-:copyright: (c) 2009 - 2011 by Ask Solem.
+:copyright: (c) 2009 - 2012 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
+from __future__ import absolute_import
+
 import weakref
 
 from itertools import count
 
+__all__ = ["Finalize"]
+
 
 class Finalize(object):
     """Object finalization using weakrefs."""
